%bcond_without qt5
%bcond_without qt6
%bcond_without check
%bcond_without amr

# disabled as we don't have hotdoc
%bcond_with docs

%define api	1.0
%define bname	gstreamer%{api}

Summary:	GStreamer Streaming-media framework plug-ins
Name:		%{bname}-plugins-good
Version:	1.26.4
Release:	%mkrel 1
License:	LGPLv2+
Group:		System/Libraries
URL:		https://gstreamer.freedesktop.org/
Source:		https://gstreamer.freedesktop.org/src/gst-plugins-good/gst-plugins-good-%{version}.tar.xz
BuildRequires:	pkgconfig(caca)
BuildRequires:	pkgconfig(cairo)
BuildRequires:	pkgconfig(cairo-gobject)
BuildRequires:	pkgconfig(flac)
BuildRequires:	pkgconfig(gdk-pixbuf-2.0)
BuildRequires:	pkgconfig(gtk+-3.0)
BuildRequires:	pkgconfig(gtk+-x11-3.0)
BuildRequires:	pkgconfig(gudev-1.0)
BuildRequires:	pkgconfig(glesv2)
BuildRequires:	pkgconfig(jack)
BuildRequires:	pkgconfig(libavc1394)
BuildRequires:	pkgconfig(libdv)
BuildRequires:	pkgconfig(libiec61883)
BuildRequires:	pkgconfig(libmpg123)
BuildRequires:	pkgconfig(libpng)
BuildRequires:	pkgconfig(libpulse)
BuildRequires:	pkgconfig(libraw1394)
BuildRequires:	pkgconfig(libsoup-3.0)
BuildRequires:	pkgconfig(libv4l2)
%if %{with qt5}
BuildRequires:	pkgconfig(Qt5Core)
BuildRequires:	pkgconfig(Qt5Gui)
BuildRequires:	pkgconfig(Qt5Help)
BuildRequires:	pkgconfig(Qt5Qml)
BuildRequires:	pkgconfig(Qt5Quick)
BuildRequires:	pkgconfig(Qt5X11Extras)
BuildRequires:	pkgconfig(Qt5WaylandClient)
BuildRequires:	qt5platformsupport-devel
%endif
%if %{with qt6}
BuildRequires:	qttools6
BuildRequires:	qt6-qtshadertools
BuildRequires:	cmake(Qt6Core)
BuildRequires:	cmake(Qt6Gui)
BuildRequires:	cmake(Qt6Qml)
BuildRequires:	cmake(Qt6Quick)
BuildRequires:	cmake(Qt6WaylandClient)
%endif

BuildRequires:	pkgconfig(nettle)
BuildRequires:	pkgconfig(shout)
BuildRequires:	pkgconfig(speex)
BuildRequires:	pkgconfig(taglib)
BuildRequires:	pkgconfig(vpx)
BuildRequires:	pkgconfig(wavpack)
BuildRequires:	pkgconfig(xdamage)
BuildRequires:	pkgconfig(xext)
BuildRequires:	pkgconfig(xfixes)
BuildRequires:	pkgconfig(xv)
BuildRequires:	aalib-devel
BuildRequires:	pkgconfig(libjpeg)
BuildRequires:	pkgconfig(bzip2)
BuildRequires:	gettext-devel
BuildRequires:	pkgconfig(check)
BuildRequires:	pkgconfig(gstreamer-plugins-base-1.0) >= %{version}
BuildRequires:	meson

%ifarch %ix86 x86_64
BuildRequires:	nasm >= 0.90
%endif

%ifarch %{valgrind_arches} %{arm32}
BuildRequires:	pkgconfig(valgrind)
%endif

%if %{with amr}
BuildRequires:	pkgconfig(opencore-amrnb)
%endif

Provides:	%{bname}-audiosrc
Provides:	%{bname}-audiosink

# gw this is the default http source:
Recommends:	%{bname}-soup

%description
GStreamer is a streaming-media framework, based on graphs of filters which
operate on media data. Applications using this library can do anything
from real-time sound processing to playing videos, and just about anything
else media-related.  Its plugin-based architecture means that new data
types or processing capabilities can be added simply by installing new
plug-ins.

This package contains a set of plug-ins that are considered to have
good quality code, correct functionality, the preferred license (LGPL
for the plug-in code, LGPL or LGPL-compatible for the supporting
library). People writing elements should base their code on these
elements.


%prep
%autosetup -p1 -n gst-plugins-good-%{version}

%build
%meson \
	-Ddoc=%{?with_docs:enabled}%{?!with_docs:disabled} \
	-Dqt5=%{?with_qt5:enabled}%{?!with_qt5:disabled} \
	-Dqt6=%{?with_qt6:enabled}%{?!with_qt6:disabled} \
	-Dexamples=disabled \
	-Dtests=disabled \
	-Drpicamsrc=disabled \
	-Damrnb=%{?with_amr:enabled}%{!?with_amr:disabled} \
	-Damrwbdec=%{?with_amr:enabled}%{!?with_amr:disabled} \
	-Dpackage-name='%{_vendor} %{name} package' \
	-Dpackage-origin='https://www.%{_real_vendor}.org/'

%meson_build

%if %{with check}
%check
%meson_test
%endif

%install
%meson_install

%find_lang gst-plugins-good-%{api}

#blino remove development doc since we don't ship devel files
rm -rf %{buildroot}%{_docdir}/docs/plugins/html %{buildroot}%{_datadir}/gtk-doc

%files -f gst-plugins-good-%{api}.lang
%license COPYING
%doc AUTHORS README.md NEWS
%{_libdir}/gstreamer-%{api}/libgstadaptivedemux2.so
%{_libdir}/gstreamer-%{api}/libgstalaw.so
%{_libdir}/gstreamer-%{api}/libgstalpha.so
%{_libdir}/gstreamer-%{api}/libgstalphacolor.so
%{_libdir}/gstreamer-%{api}/libgstapetag.so
%{_libdir}/gstreamer-%{api}/libgstaudiofx.so
%{_libdir}/gstreamer-%{api}/libgstaudioparsers.so
%{_libdir}/gstreamer-%{api}/libgstauparse.so
%{_libdir}/gstreamer-%{api}/libgstautodetect.so
%{_libdir}/gstreamer-%{api}/libgstavi.so
%{_libdir}/gstreamer-%{api}/libgstcairo.so
%{_libdir}/gstreamer-%{api}/libgstcutter.so
%{_libdir}/gstreamer-%{api}/libgstdebug.so
%{_libdir}/gstreamer-%{api}/libgstdeinterlace.so
%{_libdir}/gstreamer-%{api}/libgstdtmf.so
%{_libdir}/gstreamer-%{api}/libgsteffectv.so
%{_libdir}/gstreamer-%{api}/libgstflv.so
%{_libdir}/gstreamer-%{api}/libgstequalizer.so
%{_libdir}/gstreamer-%{api}/libgstflxdec.so
%{_libdir}/gstreamer-%{api}/libgstgdkpixbuf.so
%{_libdir}/gstreamer-%{api}/libgstgtk.so
%{_libdir}/gstreamer-%{api}/libgstgoom.so
%{_libdir}/gstreamer-%{api}/libgstgoom2k1.so
%{_libdir}/gstreamer-%{api}/libgsticydemux.so
%{_libdir}/gstreamer-%{api}/libgstid3demux.so
%{_libdir}/gstreamer-%{api}/libgstimagefreeze.so
%{_libdir}/gstreamer-%{api}/libgstinterleave.so
%{_libdir}/gstreamer-%{api}/libgstisomp4.so
%{_libdir}/gstreamer-%{api}/libgstjpeg.so
%{_libdir}/gstreamer-%{api}/libgstlevel.so
%{_libdir}/gstreamer-%{api}/libgstmatroska.so
%{_libdir}/gstreamer-%{api}/libgstmonoscope.so
%{_libdir}/gstreamer-%{api}/libgstmpg123.so
%{_libdir}/gstreamer-%{api}/libgstmulaw.so
%{_libdir}/gstreamer-%{api}/libgstmultifile.so
%{_libdir}/gstreamer-%{api}/libgstmultipart.so
%{_libdir}/gstreamer-%{api}/libgstnavigationtest.so
%{_libdir}/gstreamer-%{api}/libgstossaudio.so
%{_libdir}/gstreamer-%{api}/libgstoss4.so
%{_libdir}/gstreamer-%{api}/libgstpng.so
%if %{with qt5}
%{_libdir}/gstreamer-%{api}/libgstqmlgl.so
%endif
%if %{with qt6}
%{_libdir}/gstreamer-%{api}/libgstqml6.so
%endif
%{_libdir}/gstreamer-%{api}/libgstreplaygain.so
%{_libdir}/gstreamer-%{api}/libgstrtp.so
%{_libdir}/gstreamer-%{api}/libgstrtpmanager.so
%{_libdir}/gstreamer-%{api}/libgstrtsp.so
%{_libdir}/gstreamer-%{api}/libgstshapewipe.so
%{_libdir}/gstreamer-%{api}/libgstshout2.so
%{_libdir}/gstreamer-%{api}/libgstsmpte.so
%{_libdir}/gstreamer-%{api}/libgstspectrum.so
%{_libdir}/gstreamer-%{api}/libgsttaglib.so
%{_libdir}/gstreamer-%{api}/libgstudp.so
%{_libdir}/gstreamer-%{api}/libgstvideo4linux2.so
%{_libdir}/gstreamer-%{api}/libgstvideobox.so
%{_libdir}/gstreamer-%{api}/libgstvideocrop.so
%{_libdir}/gstreamer-%{api}/libgstvideofilter.so
%{_libdir}/gstreamer-%{api}/libgstvideomixer.so
%{_libdir}/gstreamer-%{api}/libgstwavenc.so
%{_libdir}/gstreamer-%{api}/libgstwavparse.so
%{_libdir}/gstreamer-%{api}/libgstxingmux.so
%{_libdir}/gstreamer-%{api}/libgstximagesrc.so
%{_libdir}/gstreamer-%{api}/libgsty4menc.so
%dir %{_datadir}/gstreamer-%{api}/
%dir %{_datadir}/gstreamer-%{api}/presets
%{_datadir}/gstreamer-%{api}/presets/*
%exclude %{_datadir}/gstreamer-%{api}/presets/GstAmrnbEnc.prs

%if %{with amr}
%package -n %{bname}-amrnb
Summary:	GStreamer plug-in for AMR-NB support
Group: 		Sound/Utilities
Requires:	%{bname}-plugins >= %{version}-%{release}

%description -n %{bname}-amrnb
Plug-in for decoding AMR-NB under GStreamer.

%files -n %{bname}-amrnb
%{_libdir}/gstreamer-%{api}/libgstamrnb.so
%{_datadir}/gstreamer-%{api}/presets/GstAmrnbEnc.prs

%package -n %{bname}-amrwbdec
Summary:	GStreamer plug-in for AMR-WB decoding support
Group:		Sound/Utilities
Requires:	%{bname}-plugins >= %{version}-%{release}

%description -n %{bname}-amrwbdec
Plug-in for decoding AMR-Wb under GStreamer.

%files -n %{bname}-amrwbdec
%{_libdir}/gstreamer-%{api}/libgstamrwbdec.so
%endif

%package -n %{bname}-jack
Summary:	GStreamer plug-in for the Jack Sound Server
Group:		Sound/Utilities
Provides:	%{bname}-audiosrc
Provides:	%{bname}-audiosink

%description -n %{bname}-jack
Plug-in for the JACK professional sound server.

%files -n %{bname}-jack
%{_libdir}/gstreamer-%{api}/libgstjack.so

%package -n %{bname}-soup
Summary:	GStreamer HTTP plugin based on libsoup
Group:		System/Libraries
Requires:	%{bname}-plugins >= %{version}

%description -n %{bname}-soup
Plug-in for HTTP access based on libsoup.

%files -n %{bname}-soup
%{_libdir}/gstreamer-%{api}/libgstsoup.so

%package -n %{bname}-pulse
Summary:	Pulseaudio plugin for GStreamer
Group:		Sound/Utilities
Requires:	%{bname}-plugins >= %{version}

%description -n %{bname}-pulse
This is a GStreamer audio output plugin using the Pulseaudio sound server.

%files -n %{bname}-pulse
%{_libdir}/gstreamer-%{api}/libgstpulseaudio.so

### LIBDV ###
%package -n %{bname}-dv
Summary:	GStreamer DV plug-in
Group:		Video/Utilities
Requires:	%{bname}-plugins >= %{version}

%description -n %{bname}-dv
Plug-in for digital video support using libdv.

%files -n %{bname}-dv
%{_libdir}/gstreamer-%{api}/libgstdv.so

%package -n %{bname}-speex
Summary:	Gstreamer plugin for encoding and decoding Ogg Speex audio files
Group:		Sound/Utilities
Requires:	%{bname}-plugins >= %{version}

%description -n %{bname}-speex
Plug-Ins for creating and playing Ogg Speex audio files.

%files -n %{bname}-speex
%{_libdir}/gstreamer-%{api}/libgstspeex.so

### RAW1394 ###
%package -n %{bname}-raw1394
Summary:	GStreamer raw1394 Firewire plug-in
Group:		System/Libraries
Requires:	%{bname}-plugins >= %{version}

%description -n %{bname}-raw1394
Plug-in for digital video support using raw1394.

%files -n %{bname}-raw1394
%{_libdir}/gstreamer-%{api}/libgst1394.so

### FLAC ###
%package -n %{bname}-flac
Summary:	GStreamer plug-in for FLAC lossless audio
Group:		Sound/Utilities
Requires:	%{bname}-plugins >= %{version}

%description -n %{bname}-flac
Plug-in for the free FLAC lossless audio format.

%files -n %{bname}-flac
%{_libdir}/gstreamer-%{api}/libgstflac.so

### AALIB ###
%package -n %{bname}-aalib
Summary:	Gstreamer plugin for Ascii-art output
Group:		Video/Utilities
Requires:	%{bname}-plugins >= %{version}

%description -n %{bname}-aalib
Plugin for viewing movies in Ascii-art using aalib library.

%files -n %{bname}-aalib
%{_libdir}/gstreamer-%{api}/libgstaasink.so

%package -n %{bname}-caca
Summary:	Gstreamer plugin for Ascii-art output
Group:		Video/Utilities
Requires:	%{bname}-plugins >= %{version}

%description -n %{bname}-caca
Plugin for viewing movies in Ascii-art using caca library.

%files -n %{bname}-caca
%{_libdir}/gstreamer-%{api}/libgstcacasink.so

%package -n %{bname}-vp8
Summary:	GStreamer VP8 plug-in
Group:		Video/Utilities

%description -n %{bname}-vp8
VP8 encoding and decoding plug-in.

%files -n %{bname}-vp8
%{_libdir}/gstreamer-%{api}/libgstvpx.so

%package -n %{bname}-wavpack
Summary:	Gstreamer plugin for encoding and decoding WavPack audio files
Group:		Sound/Utilities
Requires:	%{bname}-plugins >= %{version}

%description -n %{bname}-wavpack
Plug-Ins for creating and playing WavPack audio files.

%files -n %{bname}-wavpack
%{_libdir}/gstreamer-%{api}/libgstwavpack.so

### LAME ###
%package -n %{bname}-lame
Summary:        GStreamer plug-in for encoding mp3 songs using lame
Group:          Sound/Utilities
Requires:       %{bname}-plugins >= %{version}-%{release}
BuildRequires:  liblame-devel >= 3.89

%description -n %{bname}-lame
Plug-in for encoding mp3 with lame under GStreamer.

%files -n %{bname}-lame
%{_libdir}/gstreamer-%{api}/libgstlame.so

%package -n %{bname}-twolame
Summary: 	GStreamer plug-in for MP2 encoding support
Group:          Sound/Utilities
Requires:	%{bname}-plugins >= %{version}-%{release}
BuildRequires:  pkgconfig(twolame)

%description -n %{bname}-twolame
Plug-in for encoding MP2 under GStreamer.

%files -n %{bname}-twolame
%{_libdir}/gstreamer-%{api}/libgsttwolame.so


%changelog
* Sun Jul 20 2025 daviddavid <daviddavid> 1.26.4-1.mga10
+ Revision: 2257582
- new version: 1.26.4

* Sat Jul 19 2025 daviddavid <daviddavid> 1.26.3-2.mga10
+ Revision: 2257263
- rebuild for new flac 1.5.0

* Wed Jul 16 2025 daviddavid <daviddavid> 1.26.3-1.mga10
+ Revision: 2256458
- new version 1.26.3

* Mon Jul 07 2025 umeabot <umeabot> 1.26.0-2.mga10
+ Revision: 2248929
- Mageia 10 Mass Rebuild

* Wed Mar 19 2025 wally <wally> 1.26.0-1.mga10
+ Revision: 2166851
- new version 1.26.0

* Sun Mar 16 2025 wally <wally> 1.24.11-3.mga10
+ Revision: 2164848
- rebuild for libxml2 2.13.6

* Sun Jan 12 2025 daviddavid <daviddavid> 1.24.11-2.mga10
+ Revision: 2138630
- rebuild for new libvpx 1.14.1

* Tue Jan 07 2025 daviddavid <daviddavid> 1.24.11-1.mga10
+ Revision: 2135927
- new version: 1.24.11

* Sun Oct 27 2024 wally <wally> 1.24.8-1.mga10
+ Revision: 2111385
- new version 1.24.8

* Fri Oct 04 2024 daviddavid <daviddavid> 1.24.7-2.mga10
+ Revision: 2103121
- rebuild for new taglib 2.0.2

* Fri Aug 30 2024 daviddavid <daviddavid> 1.24.7-1.mga10
+ Revision: 2092237
- new version: 1.24.7

* Fri Jun 07 2024 daviddavid <daviddavid> 1.24.4-1.mga10
+ Revision: 2070356
- new version: 1.24.4

* Tue Mar 26 2024 daviddavid <daviddavid> 1.24.1-2.mga10
+ Revision: 2052218
- opencore-amr was moved to Core repo, re-enable AMR-NB gstreamer support

* Mon Mar 25 2024 daviddavid <daviddavid> 1.24.1-1.mga10
+ Revision: 2052106
- new version 1.24.1

* Sun Mar 24 2024 daviddavid <daviddavid> 1.24.0-1.mga10
+ Revision: 2051892
- new version 1.24.0
- the AMR-NB and AMR-WB plugins have been moved from -ugly to -good
+ wally <wally>
- fix valgrind BR

* Sun Feb 04 2024 wally <wally> 1.22.9-2.mga10
+ Revision: 2037167
- rebuild for arm32

* Mon Jan 29 2024 wally <wally> 1.22.9-1.mga10
+ Revision: 2036127
- new version 1.22.9

* Tue Jan 09 2024 daviddavid <daviddavid> 1.22.8-2.mga10
+ Revision: 2029168
- rebuild for arm

* Wed Dec 20 2023 ghibo <ghibo> 1.22.8-1.mga10
+ Revision: 2020051
- Update to release 1.22.8

* Mon Oct 09 2023 wally <wally> 1.22.6-1.mga10
+ Revision: 1993821
- new version 1.22.6

* Mon Oct 09 2023 daviddavid <daviddavid> 1.22.5-2.mga10
+ Revision: 1993789
- switch to libsoup3

* Fri Sep 01 2023 ghibo <ghibo> 1.22.5-1.mga10
+ Revision: 1983200
- Merge patch to fix building without Vivante Framebuffer
- Update to release 1.22.5

* Sat Jul 08 2023 ghibo <ghibo> 1.22.4-1.mga9
+ Revision: 1963700
- Update to release 1.22.4

* Sun May 21 2023 ghibo <ghibo> 1.22.3-1.mga9
+ Revision: 1957631
- Update to release 1.22.3

* Tue Jan 24 2023 wally <wally> 1.22.0-1.mga9
+ Revision: 1935697
- new version 1.22.0

* Sat Jan 14 2023 wally <wally> 1.21.90-1.mga9
+ Revision: 1933040
- new version 1.21.90
- enable Qt6 support
- move gstxingmux from -ugly

* Mon Dec 26 2022 wally <wally> 1.20.5-1.mga9
+ Revision: 1926956
- new version 1.20.5

* Sun Nov 20 2022 wally <wally> 1.20.4-1.mga9
+ Revision: 1909315
- new version 1.20.4

* Sun Nov 20 2022 wally <wally> 1.20.3-4.mga9
+ Revision: 1909261
- rebuild for flac 1.4.2

* Tue Oct 11 2022 ghibo <ghibo> 1.20.3-3.mga9
+ Revision: 1896288
- Rebuild against libvpx 1.12.0 (changed major from 6 to 7)

* Sat Jul 23 2022 wally <wally> 1.20.3-2.mga9
+ Revision: 1870431
- rebuild for core/release

* Sat Jul 23 2022 wally <wally> 1.20.3-1.mga9
+ Revision: 1870397
- new version 1.20.3

* Sun May 08 2022 wally <wally> 1.20.2-1.mga9
+ Revision: 1856821
- new version 1.20.2

* Sun Apr 03 2022 wally <wally> 1.20.1-1.mga9
+ Revision: 1841909
- new version 1.20.1

* Sat Mar 12 2022 tv <tv> 1.18.5-2.mga9
+ Revision: 1790617
- Relax pulseaudio deps for pipewire

* Sat Sep 18 2021 wally <wally> 1.18.5-1.mga9
+ Revision: 1745694
- new version 1.18.5 (mga#29452)

* Mon Apr 05 2021 wally <wally> 1.18.4-1.mga9
+ Revision: 1713701
- new version 1.18.4

* Mon Jan 18 2021 wally <wally> 1.18.3-1.mga8
+ Revision: 1672336
- new version 1.18.3

* Wed Dec 16 2020 umeabot <umeabot> 1.18.2-2.mga8
+ Revision: 1658550
- Rebuild for new Qt5

* Wed Dec 09 2020 wally <wally> 1.18.2-1.mga8
+ Revision: 1655022
- new version 1.18.2

* Sat Nov 21 2020 wally <wally> 1.18.1-1.mga8
+ Revision: 1648137
- new version 1.18.1
- drop old conflicts

* Sun Sep 13 2020 wally <wally> 1.18.0-1.mga8
+ Revision: 1625913
- new version 1.18.0

* Fri Mar 13 2020 daviddavid <daviddavid> 1.16.2-4.mga8
+ Revision: 1556026
- add BR pkgconfig(Qt5Help) for lrelease

* Fri Mar 13 2020 daviddavid <daviddavid> 1.16.2-3.mga8
+ Revision: 1556024
- switch to meson build system (GStreamer has given up on autotools...)

* Tue Feb 18 2020 umeabot <umeabot> 1.16.2-2.mga8
+ Revision: 1539228
- Mageia 8 Mass Rebuild
+ wally <wally>
- replace deprecated %%configure2_5x

* Wed Dec 04 2019 ovitters <ovitters> 1.16.2-1.mga8
+ Revision: 1464197
- new version 1.16.2

* Tue Sep 24 2019 ovitters <ovitters> 1.16.1-1.mga8
+ Revision: 1445252
- new version 1.16.1
- dropped merged patch 0001-v4l2_Fix-type-compatibility-issue-with-glibc-2.30.patch

* Tue Aug 27 2019 daviddavid <daviddavid> 1.16.0-2.mga8
+ Revision: 1434600
- add upstream patch to fix type compatibility issue with glibc 2.30 in v4l2

* Thu Apr 25 2019 wally <wally> 1.16.0-1.mga7
+ Revision: 1395268
- new version 1.16.0
- drop unneeded libvpx build fix patch

* Sat Mar 30 2019 umeabot <umeabot> 1.14.4-3.mga7
+ Revision: 1381869
- Qt5 Rebuild

* Mon Feb 11 2019 daviddavid <daviddavid> 1.14.4-2.mga7
+ Revision: 1365354
- add upstream patch to fix build against libvpx 1.8
+ zezinho <zezinho>
- rebuild for libvpx 1.8.0

* Thu Oct 04 2018 ovitters <ovitters> 1.14.4-1.mga7
+ Revision: 1317440
- new version 1.14.4

* Tue Sep 18 2018 ovitters <ovitters> 1.14.3-2.mga7
+ Revision: 1259475
- new version 1.14.3

* Fri Jul 20 2018 ovitters <ovitters> 1.14.2-1.mga7
+ Revision: 1244435
- new version 1.14.2

* Mon May 21 2018 wally <wally> 1.14.1-1.mga7
+ Revision: 1231138
- new version 1.14.1

* Mon May 21 2018 daviddavid <daviddavid> 1.14.0-2.mga7
+ Revision: 1230942
- rebuild against latest libvpx (mga#23059)

* Sat Mar 24 2018 wally <wally> 1.14.0-1.mga7
+ Revision: 1212052
- add lame and twolame from -ugly
- new version 1.14.0
- add gtk and qt plugins moved from -bad
- add mpg123 plugin moved from -ugly

* Mon Jan 29 2018 tv <tv> 1.12.4-3.mga7
+ Revision: 1197907
- rebuild for new libvpx

* Mon Jan 29 2018 cjw <cjw> 1.12.4-2.mga7
+ Revision: 1197899
- rebuild for new libvpx

* Sat Dec 16 2017 wally <wally> 1.12.4-1.mga7
+ Revision: 1182806
- disable valgrind support on arm for now
- new version 1.12.4

* Sat Sep 23 2017 ovitters <ovitters> 1.12.3-1.mga7
+ Revision: 1157975
- new version 1.12.3

* Mon Jul 24 2017 wally <wally> 1.12.2-1.mga7
+ Revision: 1130354
- new version 1.12.2

* Mon Jul 17 2017 ovitters <ovitters> 1.10.5-1.mga7
+ Revision: 1124603
- new version 1.10.5

* Fri Mar 10 2017 akien <akien> 1.10.4-2.mga6
+ Revision: 1091606
- Rebuild for v4l-utils 1.12.3
+ ovitters <ovitters>
- new version 1.10.4

* Mon Jan 30 2017 ovitters <ovitters> 1.10.3-1.mga6
+ Revision: 1084206
- new version 1.10.3

* Sat Jan 21 2017 akien <akien> 1.10.2-2.mga6
+ Revision: 1082722
- Rebuild for arm

* Sun Jan 15 2017 wally <wally> 1.10.2-1.mga6
+ Revision: 1081795
- new version 1.10.2
- drop upstreamed patches

* Thu Dec 22 2016 shlomif <shlomif> 1.8.3-3.mga6
+ Revision: 1076392
- Patch instead of remove FLC/FLI/FLX ( MGA#19830 ).
- Disable FLX/FLC/FLI ( MGA#19830 ; CVE-2016-963[4-6] ).

* Fri Aug 19 2016 luigiwalser <luigiwalser> 1.8.3-1.mga6
+ Revision: 1047096
- 1.8.3

* Fri Jun 10 2016 luigiwalser <luigiwalser> 1.8.2-1.mga6
+ Revision: 1021001
- 1.8.2

* Wed Apr 20 2016 ovitters <ovitters> 1.8.1-1.mga6
+ Revision: 1003810
- new version 1.8.1

* Thu Mar 24 2016 wally <wally> 1.8.0-2.mga6
+ Revision: 995184
- enable dependency tracking

* Thu Mar 24 2016 ovitters <ovitters> 1.8.0-1.mga6
+ Revision: 994921
- new version 1.8.0

* Tue Mar 15 2016 ovitters <ovitters> 1.7.91-1.mga6
+ Revision: 990917
- new version 1.7.91

* Tue Mar 01 2016 ovitters <ovitters> 1.7.90-1.mga6
+ Revision: 981736
- new version 1.7.90

* Sat Jan 23 2016 luigiwalser <luigiwalser> 1.6.3-1.mga6
+ Revision: 926691
- 1.6.3

* Mon Dec 14 2015 ovitters <ovitters> 1.6.2-1.mga6
+ Revision: 910463
- new version 1.6.2

* Thu Nov 19 2015 daviddavid <daviddavid> 1.6.1-2.mga6
+ Revision: 904164
- rebuild for new libvpx 1.5.0

* Fri Oct 30 2015 ovitters <ovitters> 1.6.1-1.mga6
+ Revision: 896739
- new version 1.6.1

* Sun Sep 27 2015 tv <tv> 1.6.0-1.mga6
+ Revision: 884055
- new release

* Sat Jun 27 2015 cjw <cjw> 1.4.5-2.mga6
+ Revision: 846283
- rebuild for libvpx 1.4

* Sun Jun 21 2015 luigiwalser <luigiwalser> 1.4.5-1.mga6
+ Revision: 836950
- 1.4.5

* Sat Jun 20 2015 ovitters <ovitters> 1.4.4-1.mga6
+ Revision: 836390
- new version 1.4.4

* Wed Oct 15 2014 umeabot <umeabot> 1.4.3-2.mga5
+ Revision: 741982
- Second Mageia 5 Mass Rebuild

* Sun Sep 28 2014 wally <wally> 1.4.3-1.mga5
+ Revision: 731366
- new version 1.4.3

* Sat Sep 27 2014 tv <tv> 1.4.1-3.mga5
+ Revision: 726433
- rebuild for missing pythoneggs deps

* Tue Sep 16 2014 umeabot <umeabot> 1.4.1-2.mga5
+ Revision: 679986
- Mageia 5 Mass Rebuild
+ tv <tv>
- s/uggests:/Recommends:/

* Thu Aug 28 2014 ovitters <ovitters> 1.4.1-1.mga5
+ Revision: 668982
- new version 1.4.1

* Tue Jul 29 2014 tv <tv> 1.4.0-2.mga5
+ Revision: 657829
- rebuild with fixed gcc (might fix ff & shotwell)

* Mon Jul 21 2014 fwang <fwang> 1.4.0-1.mga5
+ Revision: 654960
- disable gtk-doc
- 1.4.0

* Sat Apr 19 2014 fwang <fwang> 1.2.4-1.mga5
+ Revision: 616988
- 1.2.4

* Sun Feb 09 2014 fwang <fwang> 1.2.3-1.mga5
+ Revision: 587304
- 1.2.3

* Thu Jan 23 2014 gw666 <gw666> 1.2.2-1.mga4
+ Revision: 567576
- new version (bug #12142)

* Mon Oct 21 2013 umeabot <umeabot> 1.2.0-2.mga4
+ Revision: 536916
- Mageia 4 Mass Rebuild

* Tue Sep 24 2013 ovitters <ovitters> 1.2.0-1.mga4
+ Revision: 485280
- new version 1.2.0

* Sat Sep 21 2013 fwang <fwang> 1.1.90-2.mga4
+ Revision: 483079
- obsolete rather than conflicts

* Sat Sep 21 2013 fwang <fwang> 1.1.90-1.mga4
+ Revision: 483031
- add file list
- add more br
- new version 1.1.90

* Thu Aug 29 2013 fwang <fwang> 1.0.10-1.mga4
+ Revision: 472794
- new version 1.0.10

* Thu Aug 01 2013 fwang <fwang> 1.0.9-1.mga4
+ Revision: 461936
- new version 1.0.9
+ ovitters <ovitters>
- new version 1.0.8

* Mon Jun 03 2013 fwang <fwang> 1.0.7-2.mga4
+ Revision: 435955
- rebuild for new libpng

* Fri May 24 2013 fwang <fwang> 1.0.7-1.mga4
+ Revision: 425848
- new version 1.0.7

* Sat Jan 12 2013 umeabot <umeabot> 1.0.5-2.mga3
+ Revision: 352760
- Mass Rebuild - https://wiki.mageia.org/en/Feature:Mageia3MassRebuild

* Wed Jan 09 2013 fwang <fwang> 1.0.5-1.mga3
+ Revision: 343523
- update file list
+ ovitters <ovitters>
- new version 1.0.5

* Thu Dec 20 2012 cjw <cjw> 1.0.4-1.mga3
+ Revision: 333505
- 1.0.4

* Fri Nov 23 2012 fwang <fwang> 1.0.3-1.mga3
+ Revision: 321183
- new version 1.0.3

* Thu Nov 08 2012 colin <colin> 1.0.2-2.mga3.tainted
+ Revision: 316272
- Enable the vp8 plugin (needed for cheese)

* Thu Oct 25 2012 ovitters <ovitters> 1.0.2-1.mga3
+ Revision: 309973
- new version 1.0.2

* Mon Oct 08 2012 fwang <fwang> 1.0.1-1.mga3
+ Revision: 303321
- new version 1.0.1
- drop unused switches

* Tue Sep 18 2012 fwang <fwang> 0.11.99-1.mga3
+ Revision: 295746
- bump req
+ ovitters <ovitters>
- new version 0.11.99

* Sat Sep 15 2012 fwang <fwang> 0.11.94-2.mga3
+ Revision: 294178
- rebuild for rpm gst1.0 provides
+ ovitters <ovitters>
- clean spec

* Fri Sep 14 2012 fwang <fwang> 0.11.94-1.mga3
+ Revision: 293808
- update file list
- new version 0.11.94

* Wed Sep 05 2012 ovitters <ovitters> 0.11.93-2.mga3
+ Revision: 288290
- clean spec

* Tue Sep 04 2012 ovitters <ovitters> 0.11.93-1.mga3
+ Revision: 288276
- imported package gstreamer1.0-plugins-good

